Description Usage Arguments Value Examples
Probabilities to select a normalization set without DE-gene
1 | select_prob(m, k, invariant = TRUE)
|
m, |
number of genes |
k, |
normalization subset size |
invariant, |
boolean, when TRUE, probability of selection is evaluated for invariant gene |
a vector of probabilities of having at least one differential expression used as an reference selected in the normalization subset for any number of differential expressions d in the gene collection.
1 | select_prob(500, 10, invariant=TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.